==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/ResourceRequirementsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.ResourceRequirementsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * This type describes the resource requirements for a container or a service.
 * @property limits Describes the maximum limits on the resources for a given container.
 * @property requests Describes the requested resources for a given container.
 */
public data class ResourceRequirementsArgs(
    public val limits: Output<ResourceLimitsArgs>? = null,
    public val requests: Output<ResourceRequestsArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.ResourceRequirementsArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.ResourceRequirementsArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.ResourceRequirementsArgs.builder()
            .limits(limits?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .requests(requests.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ResourceRequirementsArgs].
 */
@PulumiTagMarker
public class ResourceRequirementsArgsBuilder internal constructor() {
    private var limits: Output<ResourceLimitsArgs>? = null

    private var requests: Output<ResourceRequestsArgs>? = null

    /**
     * @param value Describes the maximum limits on the resources for a given container.
     */
    @JvmName("yjtyxuocnsccvavp")
    public suspend fun limits(`value`: Output<ResourceLimitsArgs>) {
        this.limits = value
    }

    /**
     * @param value Describes the requested resources for a given container.
     */
    @JvmName("oxpoxuoutprqywca")
    public suspend fun requests(`value`: Output<ResourceRequestsArgs>) {
        this.requests = value
    }

    /**
     * @param value Describes the maximum limits on the resources for a given container.
     */
    @JvmName("acaaijiuxpwofhts")
    public suspend fun limits(`value`: ResourceLimitsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.limits = mapped
    }

    /**
     * @param argument Describes the maximum limits on the resources for a given container.
     */
    @JvmName("ntfftqjcfxsscajh")
    public suspend fun limits(argument: suspend ResourceLimitsArgsBuilder.() -> Unit) {
        val toBeMapped = ResourceLimitsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.limits = mapped
    }

    /**
     * @param value Describes the requested resources for a given container.
     */
    @JvmName("ylywqjnkeobkqouy")
    public suspend fun requests(`value`: ResourceRequestsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requests = mapped
    }

    /**
     * @param argument Describes the requested resources for a given container.
     */
    @JvmName("jqhkmpoecqpflywb")
    public suspend fun requests(argument: suspend ResourceRequestsArgsBuilder.() -> Unit) {
        val toBeMapped = ResourceRequestsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.requests = mapped
    }

    internal fun build(): ResourceRequirementsArgs = ResourceRequirementsArgs(
        limits = limits,
        requests = requests ?: throw PulumiNullFieldException("requests"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/ResourceRequirementsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.ResourceRequirementsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * This type describes the resource requirements for a container or a service.
 * @property limits Describes the maximum limits on the resources for a given container.
 * @property requests Describes the requested resources for a given container.
 */
public data class ResourceRequirementsArgs(
    public val limits: Output<ResourceLimitsArgs>? = null,
    public val requests: Output<ResourceRequestsArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.ResourceRequirementsArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.ResourceRequirementsArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.ResourceRequirementsArgs.builder()
            .limits(limits?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .requests(requests.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ResourceRequirementsArgs].
 */
@PulumiTagMarker
public class ResourceRequirementsArgsBuilder internal constructor() {
    private var limits: Output<ResourceLimitsArgs>? = null

    private var requests: Output<ResourceRequestsArgs>? = null

    /**
     * @param value Describes the maximum limits on the resources for a given container.
     */
    @JvmName("omhfgvowcibxmrmo")
    public suspend fun limits(`value`: Output<ResourceLimitsArgs>) {
        this.limits = value
    }

    /**
     * @param value Describes the requested resources for a given container.
     */
    @JvmName("efwgljpjnbiqvcve")
    public suspend fun requests(`value`: Output<ResourceRequestsArgs>) {
        this.requests = value
    }

    /**
     * @param value Describes the maximum limits on the resources for a given container.
     */
    @JvmName("uythmnqbwugoqkyi")
    public suspend fun limits(`value`: ResourceLimitsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.limits = mapped
    }

    /**
     * @param argument Describes the maximum limits on the resources for a given container.
     */
    @JvmName("oagacwphujgsiclj")
    public suspend fun limits(argument: suspend ResourceLimitsArgsBuilder.() -> Unit) {
        val toBeMapped = ResourceLimitsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.limits = mapped
    }

    /**
     * @param value Describes the requested resources for a given container.
     */
    @JvmName("kheuekgqimtmmgkq")
    public suspend fun requests(`value`: ResourceRequestsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requests = mapped
    }

    /**
     * @param argument Describes the requested resources for a given container.
     */
    @JvmName("vwjrpuomauivmiks")
    public suspend fun requests(argument: suspend ResourceRequestsArgsBuilder.() -> Unit) {
        val toBeMapped = ResourceRequestsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.requests = mapped
    }

    internal fun build(): ResourceRequirementsArgs = ResourceRequirementsArgs(
        limits = limits,
        requests = requests ?: throw PulumiNullFieldException("requests"),
    )
}
